==> kubernetes-model-1.0.62-sources.jar: io/fabric8/kubernetes/api/model/HostPathVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class HostPathVolumeSourceBuilder extends HostPathVolumeSourceFluentImpl<HostPathVolumeSourceBuilder> implements VisitableBuilder<HostPathVolumeSource,HostPathVolumeSourceBuilder>{

    HostPathVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public HostPathVolumeSourceBuilder(){
            this(true);
    }
    public HostPathVolumeSourceBuilder(Boolean validationEnabled){
            this(new HostPathVolumeSource(), validationEnabled);
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new HostPathVolumeSource(), validationEnabled);
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSourceFluent<?> fluent,HostPathVolumeSource instance){
            this(fluent, instance, true);
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSourceFluent<?> fluent,HostPathVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withPath(instance.getPath()); 
            this.validationEnabled = validationEnabled; 
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSource instance){
            this(instance,true);
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withPath(instance.getPath()); 
            this.validationEnabled = validationEnabled; 
    }

    public HostPathVolumeSource build(){
            HostPathVolumeSource buildable = new HostPathVolumeSource(fluent.getPath());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            HostPathVolumeSourceBuilder that = (HostPathVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/kubernetes/api/model/HostPathVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class HostPathVolumeSourceBuilder extends HostPathVolumeSourceFluentImpl<HostPathVolumeSourceBuilder> implements VisitableBuilder<HostPathVolumeSource,HostPathVolumeSourceBuilder>{

    HostPathVolumeSourceFluent<?> fluent;
    Boolean validationEnabled;

    public HostPathVolumeSourceBuilder(){
            this(true);
    }
    public HostPathVolumeSourceBuilder(Boolean validationEnabled){
            this(new HostPathVolumeSource(), validationEnabled);
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSourceFluent<?> fluent){
            this(fluent, true);
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSourceFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new HostPathVolumeSource(), validationEnabled);
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSourceFluent<?> fluent,HostPathVolumeSource instance){
            this(fluent, instance, true);
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSourceFluent<?> fluent,HostPathVolumeSource instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withPath(instance.getPath()); 
            this.validationEnabled = validationEnabled; 
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSource instance){
            this(instance,true);
    }
    public HostPathVolumeSourceBuilder(HostPathVolumeSource instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withPath(instance.getPath()); 
            this.validationEnabled = validationEnabled; 
    }

    public HostPathVolumeSource build(){
            HostPathVolumeSource buildable = new HostPathVolumeSource(fluent.getPath());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            HostPathVolumeSourceBuilder that = (HostPathVolumeSourceBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
